@@ -1,3 +1,3 @@
 from .module import os_load
 from .module import os_stop
-from .module import helloworld
\ No newline at end of file
+from .module import random, app_command, help, ver
\ No newline at end of file
